/**
 * @file main.c
 * @brief Main function for SlideSwitch TFT Designer Application.
 */

#include "vtft.h"
#include "gl.h"
#include "main_screen.h"
#include "scr_main_screen.h"
#include "touch_controller.h"

static gl_driver_t display_driver;
static tp_t tp;
static vtft_t vtft;
static tp_drv_t tp_interface;

extern bool SlideSwitch_0_state ;
extern bool SlideSwitch_1_state ;
extern bool SlideSwitch_2_state ;
extern bool SlideSwitch_3_state ;
extern bool on_change ;


void board_init()
{
    touch_controller_init(&display_driver, TFT8_MAX_BACKLIGHT);
    // Initialize Graphic library.
    gl_set_driver(&display_driver);

    touch_controller_tp_init(&tp, &tp_interface);
}

/**
 * @brief Application initialization function.
 */
void application_init()
{
    board_init();

    // Initialize VTFT library.
    vtft_init(&vtft, &tp);
    main_screen_show(&vtft);
}

/**
 * @brief Application task function.
 */
void application_task()
{
    vtft_process(&vtft);

    //  Set or reset border
    if ( SlideSwitch_0_state )
    {
        main_screen.RoundedButton->pen.width = 8 ;
    } else {
        main_screen.RoundedButton->pen.width = 0 ;
    }

    //  Set or reset gradient
    if ( SlideSwitch_1_state )
    {
        main_screen.RoundedButton->press_gradient.gradient_style = VTFT_GRADIENT_TOP_BOTTOM ;
    } else {
        main_screen.RoundedButton->press_gradient.gradient_style = VTFT_GRADIENT_NONE ;
    }

    //  Set or reset visibility
    if ( SlideSwitch_2_state )
    {
//      main_screen.RoundedButton->visible = 1 ;
//      main_screen.RoundedBox->active  = 1 ;
        main_screen.RoundedButton->press_gradient.transparent = 1 ;
    } else {
//      main_screen.RoundedButton->visible = 0 ;
//      main_screen.RoundedBox->active  = 0 ;
        main_screen.RoundedButton->press_gradient.transparent = 0 ;
    }

    //  Set text color
    if ( SlideSwitch_3_state )
    {
        main_screen.RoundedButton->text.font.color = GL_BLACK ;
    } else {
        main_screen.RoundedButton->text.font.color = GL_WHITE ;
    }
    
    if ( on_change == true )
    {
        on_change = false ;
        vtft_draw_component( &vtft, ( vtft_component * ) main_screen.RoundedButton) ;
    }
}

/**
 * @brief Application main function.
 */
void main()
{
#ifdef DEBUG
    Delay_ms(500) ;
#endif
    application_init();

    while (1)
    {
        application_task();
    }
}
